@@ -22,7 +22,7 @@ gtk.gdk.threads_init()
 #This is to be able to start Feed Circuit on PC
 try:
     import osso
-    osso_context = osso.Context("org.maemo.feedcircuit", "0.6.1", False)
+    osso_context = osso.Context("org.maemo.feedcircuit", "0.6.2", False)
 except ImportError:
     pass
 
@@ -130,7 +130,8 @@ class FeedConfig:
 
 
     def __init__(self, url, name, mode, days_to_keep,
-        include, exclude, ignore_print_version, icon_filename, message_count, id = None):
+        include, exclude, ignore_print_version, icon_filename,
+        message_count, as_is, content_tag, id = None):
         self.id = id
         if not self.id:
             self.id = uuid.uuid1().hex
@@ -143,6 +144,8 @@ class FeedConfig:
         self.ignore_print_version = ignore_print_version
         self.icon_filename = icon_filename
         self.message_count = message_count
+        self.as_is = as_is
+        self.content_tag = content_tag
         self.icon = None
         self.iter = None
         self.ord_num = 0
@@ -173,6 +176,21 @@ class FeedConfig:
         return self.name
 
 
+    def get_content_kwargs(self):
+        result = {}
+        if self.content_tag:
+            parts = self.content_tag.split(" ")
+            if len(parts):
+                result["name"] = parts[0]
+                result["attrs"] = {}
+                for part in parts[1:]:
+                    name_val = part.split("=")
+                    if len(name_val) == 2:
+                        result["attrs"][name_val[0]] = \
+                            name_val[1].replace('"', "").replace("&quot;", '"')
+        return result
+
+
 class FeedListModel(gtk.GenericTreeModel):
 
 
@@ -264,6 +282,8 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.getboolean_default(section, "ignore print version", False),
                 parser.get_default(section, "icon", ""),
                 parser.getint_default(section, "message count", 0),
+                parser.getboolean_default(section, "as is", False),
+                parser.get_default(section, "content tag", ""),
                 section)
             feed_config.ord_num = parser.getint_default(section, "order number", 0)
             self.list.append(feed_config)
@@ -287,6 +307,8 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.set(feed_config.id, "ignore print version", str(feed_config.ignore_print_version))
                 parser.set(feed_config.id, "icon", feed_config.icon_filename)
                 parser.set(feed_config.id, "message count", str(feed_config.message_count))
+                parser.set(feed_config.id, "as is", str(feed_config.as_is))
+                parser.set(feed_config.id, "content tag", feed_config.content_tag)
                 parser.set(feed_config.id, "order number", str(i))
                 i += 1
             parser.write(f)
@@ -341,7 +363,7 @@ class AddWindow(gtk.Dialog):
         self.show_all()
 
 
-class AdvancedWindow(gtk.Dialog):
+class ExtraWindow(gtk.Dialog):
 
 
     def __init__(self, parent):
@@ -349,26 +371,56 @@ class AdvancedWindow(gtk.Dialog):
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
             (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
              gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-        self.set_title(_("Advanced feed settings"))
+        self.set_title(_("Extra feed settings"))
         self.days_editor = hildon.NumberEditor(1, 365)
-        self.ignore_print_version_button = gtk.CheckButton()
         self.include_entry = gtk.Entry()
         self.include_entry.set_width_chars(24)
         self.exclude_entry = gtk.Entry()
         table = gtk.Table(rows = 4, columns = 2)
-        texts = [_("Days to keep"), _("Ignore print version"), _("Include pattern"), _("Exclude pattern") ]
+        texts = [_("Days to keep"), _("Include pattern"), _("Exclude pattern") ]
         for i in range(0, len(texts)):
             label = gtk.Label(texts[i])
             label.set_alignment(1, 1)
             table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
         table.attach(self.days_editor, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
-        table.attach(self.ignore_print_version_button, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
-        table.attach(self.include_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
-        table.attach(self.exclude_entry, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        table.attach(self.include_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
+        table.attach(self.exclude_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
 
+class ContentWindow(gtk.Dialog):
+
+
+    def __init__(self, parent):
+        gtk.Dialog.__init__(self, None, parent,
+            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+             gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+        self.set_title(_("Content settings"))
+        self.as_is_button = gtk.CheckButton()
+        self.as_is_button.connect("toggled", self.as_is_changed)
+        self.ignore_print_version_button = gtk.CheckButton()
+        self.content_tag_entry = gtk.Entry()
+        self.content_tag_entry.set_width_chars(24)
+        table = gtk.Table(rows = 3, columns = 2)
+        texts = [_("Use as is"), _("Ignore print version"), _("Content tag") ]
+        for i in range(0, len(texts)):
+            label = gtk.Label(texts[i])
+            label.set_alignment(1, 1)
+            table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
+        table.attach(self.as_is_button, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
+        table.attach(self.ignore_print_version_button, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
+        table.attach(self.content_tag_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        self.vbox.add(table)
+        self.show_all()
+
+
+    def as_is_changed(self, source):
+        self.ignore_print_version_button.set_sensitive(not self.as_is_button.get_active())
+        self.content_tag_entry.set_sensitive(not self.as_is_button.get_active())
+
+
 class EditWindow(gtk.Dialog):
 
 
@@ -383,18 +435,26 @@ class EditWindow(gtk.Dialog):
         self.include = feed_config.include
         self.exclude = feed_config.exclude
         self.ignore_print_version = feed_config.ignore_print_version
+        self.as_is = feed_config.as_is
+        self.content_tag = feed_config.content_tag
         self.url_entry = gtk.Entry()
         self.url_entry.set_width_chars(32)
         self.url_entry.set_text(feed_config.url)
         self.name_entry = gtk.Entry()
         self.name_entry.set_text(feed_config.name)
+        hbox = gtk.HBox(spacing = 3)
+        self.content_button = gtk.Button(_("Advanced"))
+        self.content_button.connect("clicked", self.content_clicked)
         self.mode_combo = gtk.combo_box_new_text()
+        self.mode_combo.connect("changed", self.mode_changed)
         self.mode_combo.append_text(_("Do nothing"))
         self.mode_combo.append_text(_("Cache"))
         self.mode_combo.append_text(_("Inline"))
         self.mode_combo.set_active(feed_config.mode)
-        self.advanced_button = gtk.Button(_("Advanced"))
-        self.advanced_button.connect("clicked", self.advanced_clicked)
+        hbox.pack_start(self.mode_combo)
+        hbox.pack_start(self.content_button, expand = False)
+        self.extra_button = gtk.Button(_("Extra settings"))
+        self.extra_button.connect("clicked", self.extra_clicked)
         table = gtk.Table(rows = 4, columns = 2)
         texts = [_("Url"), _("Name"), _("Content")]
         for i in range(0, len(texts)):
@@ -403,13 +463,18 @@ class EditWindow(gtk.Dialog):
             table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
         table.attach(self.url_entry, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
         table.attach(self.name_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
-        table.attach(self.mode_combo, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(hbox, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
         hbox = gtk.HBox()
-        hbox.pack_end(self.advanced_button, expand = False)
+        hbox.pack_end(self.extra_button, expand = False)
         table.attach(hbox, 1, 2, 3, 4, xpadding = 3, ypadding = 8)
         self.vbox.add(table)
         self.show_all()
 
+
+    def mode_changed(self, source):
+        self.content_button.set_sensitive(self.mode_combo.get_active() != FeedConfig.mode_ommit)
+
+
     def update_feed(self):
         self.feed_config.url = self.url_entry.get_text()
         self.feed_config.name = self.name_entry.get_text()
@@ -417,21 +482,33 @@ class EditWindow(gtk.Dialog):
         self.feed_config.days_to_keep = self.days_to_keep
         self.feed_config.include = self.include
         self.feed_config.exclude = self.exclude
+        self.feed_config.as_is = self.as_is
         self.feed_config.ignore_print_version = self.ignore_print_version
+        self.feed_config.content_tag = self.content_tag
 
 
-    def advanced_clicked(self, source):
-        adv_window = AdvancedWindow(self)
-        adv_window.days_editor.set_value(self.days_to_keep)
-        adv_window.ignore_print_version_button.set_active(self.ignore_print_version)
-        adv_window.include_entry.set_text(self.include)
-        adv_window.exclude_entry.set_text(self.exclude)
-        if adv_window.run() == gtk.RESPONSE_ACCEPT:
-            self.days_to_keep = adv_window.days_editor.get_value()
-            self.ignore_print_version = adv_window.ignore_print_version_button.get_active()
-            self.include = adv_window.include_entry.get_text()
-            self.exclude = adv_window.exclude_entry.get_text()
-        adv_window.destroy()
+    def extra_clicked(self, source):
+        ext_window = ExtraWindow(self)
+        ext_window.days_editor.set_value(self.days_to_keep)
+        ext_window.include_entry.set_text(self.include)
+        ext_window.exclude_entry.set_text(self.exclude)
+        if ext_window.run() == gtk.RESPONSE_ACCEPT:
+            self.days_to_keep = ext_window.days_editor.get_value()
+            self.include = ext_window.include_entry.get_text()
+            self.exclude = ext_window.exclude_entry.get_text()
+        ext_window.destroy()
+
+
+    def content_clicked(self, source):
+        cnt_window = ContentWindow(self)
+        cnt_window.as_is_button.set_active(self.as_is)
+        cnt_window.ignore_print_version_button.set_active(self.ignore_print_version)
+        cnt_window.content_tag_entry.set_text(self.content_tag)
+        if cnt_window.run() == gtk.RESPONSE_ACCEPT:
+            self.as_is = cnt_window.as_is_button.get_active()
+            self.ignore_print_version = cnt_window.ignore_print_version_button.get_active()
+            self.content_tag = cnt_window.content_tag_entry.get_text()
+        cnt_window.destroy()
 
 
 class Program(hildon.Program):
@@ -484,6 +561,7 @@ class Program(hildon.Program):
         self.__view = gtk.TreeView(self.__model)
         self.__view.set_rubber_banding(True)
         self.__view.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
+
         col = gtk.TreeViewColumn()
         render_pixbuf = gtk.CellRendererPixbuf()
         col.pack_start(render_pixbuf, expand=False)
@@ -492,11 +570,13 @@ class Program(hildon.Program):
         col.pack_start(render_text, expand=True)
         col.add_attribute(render_text, 'markup', 1)
         self.__view.append_column(col)
+        
         col = gtk.TreeViewColumn()
         render_text = gtk.CellRendererText()
         col.pack_start(render_text, expand=False)
         col.add_attribute(render_text, 'text', 2)
         self.__view.append_column(col)
+
         self.__view.connect("row_activated", self.row_activated)
 
         self.__window.add(self.__view)
@@ -622,7 +702,8 @@ class Program(hildon.Program):
                     delete_before_date = date.today() - timedelta(feed_config.days_to_keep),
                     inline_items = feed_config.mode == FeedConfig.mode_inline,
                     cache_items = feed_config.mode == FeedConfig.mode_cache,
-                    include = feed_config.include, exclude = feed_config.exclude)
+                    include = feed_config.include, exclude = feed_config.exclude,
+                    as_is = feed_config.as_is, content_kwargs = feed_config.get_content_kwargs())
                 new_item_count = feed.update()
                 gobject.idle_add(self.feed_updated, feed_config, new_item_count)
         finally:
@@ -680,7 +761,7 @@ class Program(hildon.Program):
                     urllib.urlretrieve(icon_url, os.path.join(create_config_dir(), icon_filename))
             except Exception, ex:
                 pass
-            feed_config =FeedConfig(url, title, FeedConfig.mode_ommit, 7, "", "", False, icon_filename, 0)
+            feed_config =FeedConfig(url, title, FeedConfig.mode_ommit, 7, "", "", False, icon_filename, 0, False, "")
             edit_window = EditWindow(self.__window, feed_config)
             if edit_window.run() == gtk.RESPONSE_ACCEPT:
                 edit_window.update_feed()
@@ -714,7 +795,7 @@ class Program(hildon.Program):
     def about(self, source):
         dialog = gtk.AboutDialog()
         dialog.set_name("FeedCircuit")
-        dialog.set_version("0.6.1")
+        dialog.set_version("0.6.2")
         dialog.set_website("http://feedcircuit.garage.maemo.org")
         dialog.set_authors([_("George Kibardin")])
         dialog.run()
